summaryrefslogtreecommitdiffstats
path: root/arts/builder
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:11 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:49:11 -0600
commit83fbc82a101309e171089f0d5ed080f82a367345 (patch)
treec7b61083b6e2d4bfceaace9a7f018181ea36afec /arts/builder
parentb248983f92b865ef74636ab5a673ae3a88f79c20 (diff)
downloadtdemultimedia-83fbc82a101309e171089f0d5ed080f82a367345.tar.gz
tdemultimedia-83fbc82a101309e171089f0d5ed080f82a367345.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'arts/builder')
-rw-r--r--arts/builder/createtool.cpp10
-rw-r--r--arts/builder/dirmanager.cpp2
-rw-r--r--arts/builder/execdlg.cpp58
-rw-r--r--arts/builder/execdlg.h4
-rw-r--r--arts/builder/interfacedlg.cpp60
-rw-r--r--arts/builder/main.cpp8
-rw-r--r--arts/builder/module.cpp2
-rw-r--r--arts/builder/portposdlg.cpp56
-rw-r--r--arts/builder/propertypanel.cpp10
-rw-r--r--arts/builder/propertypanel.h2
-rw-r--r--arts/builder/propertypanelbase.ui2
-rw-r--r--arts/builder/qttableview.cpp66
-rw-r--r--arts/builder/qttableview.h14
-rw-r--r--arts/builder/retrievedlg.cpp44
-rw-r--r--arts/builder/retrievedlg.h2
-rw-r--r--arts/builder/structureport.cpp2
16 files changed, 171 insertions, 171 deletions
diff --git a/arts/builder/createtool.cpp b/arts/builder/createtool.cpp
index f8d5c7e5..ef26009f 100644
--- a/arts/builder/createtool.cpp
+++ b/arts/builder/createtool.cpp
@@ -25,7 +25,7 @@
#include "structureport.h"
//#include <arts/debug.h>
-#include <tqpalette.h>
+#include <palette.h>
#include <tqpainter.h>
#include <kmessagebox.h>
#include <klocale.h>
@@ -55,7 +55,7 @@ CreateTool::CreateTool(ModuleWidget *mwidget)
CreateTool::~CreateTool()
{
- mwidget->tqrepaint(componentRect);
+ mwidget->repaint(componentRect);
mwidget->setCursor(oldCursor);
mwidget->setMouseTracking(oldMouseTracking);
}
@@ -89,7 +89,7 @@ void CreateTool::mouseMoveEvent(TQMouseEvent *e)
&& mwidget->colXPos(x + width, &cellx2) && mwidget->rowYPos(y + height, &celly2);
if(!posok) return;
- mwidget->tqrepaint(componentRect);
+ mwidget->repaint(componentRect);
componentRect = TQRect(cellx, celly, cellx2 - cellx, celly2 - celly);
TQPainter *p = new TQPainter;
@@ -303,7 +303,7 @@ void ConnectPortsTool::mouseMoveEvent(TQMouseEvent *e)
{
TQPainter painter(mwidget);
painter.setPen(TQt::white);
- mwidget->tqrepaint(TQRect(firstPos, lastPos).normalize());
+ mwidget->repaint(TQRect(firstPos, lastPos).normalize());
painter.drawLine(firstPos, e->pos());
lastPos = e->pos();
}
@@ -334,6 +334,6 @@ void ConnectPortsTool::mouseReleaseEvent(TQMouseEvent *e)
}
}
}
- mwidget->tqrepaint(TQRect(firstPos, lastPos).normalize());
+ mwidget->repaint(TQRect(firstPos, lastPos).normalize());
mwidget->leaveTool(this);
}
diff --git a/arts/builder/dirmanager.cpp b/arts/builder/dirmanager.cpp
index dae660b2..2f22f104 100644
--- a/arts/builder/dirmanager.cpp
+++ b/arts/builder/dirmanager.cpp
@@ -83,7 +83,7 @@ char *DirManager::directory(const char *subdir, const TQString &desc)
TQString dir = TQFile::decodeName(dirname);
message = i18n("You need the folder %1.\n"
"It will be used to store %2.\nShould I create it now?")
- .tqarg(dir).tqarg(desc);
+ .arg(dir).arg(desc);
if(KMessageBox::questionYesNo(0,message,i18n("aRts Folder Missing"),i18n("Create Folder"),i18n("Do Not Create"))
== KMessageBox::Yes)
diff --git a/arts/builder/execdlg.h b/arts/builder/execdlg.h
index 61348c0f..7c2c6d78 100644
--- a/arts/builder/execdlg.h
+++ b/arts/builder/execdlg.h
@@ -27,7 +27,7 @@
#include <tqtimer.h>
#include <tqlabel.h>
#include <tqscrollbar.h>
-#include <tqlayout.h>
+#include <layout.h>
class ExecDlg :public TQDialog {
Q_OBJECT
@@ -35,7 +35,7 @@ class ExecDlg :public TQDialog {
public:
TQTimer *cpuusagetimer;
TQLabel *cpuusagelabel;
- TQVBoxLayout *maintqlayout,*slidertqlayout;
+ TQVBoxLayout *mainlayout,*sliderlayout;
ExecutableStructure *structure;
void start();
diff --git a/arts/builder/interfacedlg.cpp b/arts/builder/interfacedlg.cpp
index 3b4d455a..4d57c954 100644
--- a/arts/builder/interfacedlg.cpp
+++ b/arts/builder/interfacedlg.cpp
@@ -21,7 +21,7 @@
#include "interfacedlg.h"
#include "structureport.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
#include <kbuttonbox.h>
@@ -45,46 +45,46 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
{
setCaption(i18n("aRts: Structureport View"));
- TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
- //TQHBoxLayout *contentstqlayout = new TQHBoxLayout;
+ TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
+ //TQHBoxLayout *contentslayout = new TQHBoxLayout;
// object type
/*
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
TQLabel *objectlabel = new TQLabel(this);
TQFont labelfont(objectlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
objectlabel->setFont(labelfont);
objectlabel->setText(TQString(" ")+i18n("Object type: ")+TQString(port->owner->name())+TQString(" "));
- objectlabel->tqsetAlignment(AlignCenter);
+ objectlabel->setAlignment(AlignCenter);
min_size(objectlabel);
- maintqlayout->addWidget(objectlabel);
+ mainlayout->addWidget(objectlabel);
*/
// port description
/*
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
TQLabel *portlabel = new TQLabel(this);
labelfont.setPointSize(labelfont.pointSize()*4/5);
portlabel->setFont(labelfont);
portlabel->setText(i18n("Port description: ")+ port->description);
min_size(portlabel);
- portlabel->tqsetAlignment(AlignCenter);
- maintqlayout->addWidget(portlabel);
+ portlabel->setAlignment(AlignCenter);
+ mainlayout->addWidget(portlabel);
- int labelwidth = imax(portlabel->tqsizeHint().width(),objectlabel->tqsizeHint().width());
+ int labelwidth = imax(portlabel->sizeHint().width(),objectlabel->sizeHint().width());
portlabel->setMinimumWidth(labelwidth);
objectlabel->setMinimumWidth(labelwidth);
// hruler
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(ruler);
- maintqlayout->addSpacing(5);
- maintqlayout->addLayout(contentstqlayout);
+ mainlayout->addWidget(ruler);
+ mainlayout->addSpacing(5);
+ mainlayout->addLayout(contentslayout);
*/
// list
@@ -93,23 +93,23 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
update();
listbox->setMinimumSize(340,400);
- maintqlayout->addWidget(listbox);
+ mainlayout->addWidget(listbox);
connect( listbox, TQT_SIGNAL( doubleClicked ( TQListBoxItem *)), this,
TQT_SLOT(accept()));
// hruler
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(ruler2);
+ mainlayout->addWidget(ruler2);
// buttons
- TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
- maintqlayout->addSpacing(5);
- maintqlayout->addLayout(buttontqlayout);
- maintqlayout->addSpacing(5);
+ TQHBoxLayout *buttonlayout = new TQHBoxLayout;
+ mainlayout->addSpacing(5);
+ mainlayout->addLayout(buttonlayout);
+ mainlayout->addSpacing(5);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -121,14 +121,14 @@ InterfaceDlg::InterfaceDlg(TQWidget *parent) :TQDialog(parent,"Props", TRUE)
TQButton *cancelbutton = bbox->addButton(KStdGuiItem::cancel());
connect( cancelbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(reject() ) );
- bbox->tqlayout();
+ bbox->layout();
//min_size(bbox);
- buttontqlayout->addWidget(bbox);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addWidget(bbox);
+ buttonlayout->addSpacing(5);
- //maintqlayout->activate();
- maintqlayout->freeze();
+ //mainlayout->activate();
+ mainlayout->freeze();
}
string InterfaceDlg::interfaceName()
@@ -159,10 +159,10 @@ void InterfaceDlg::update(const string& interface, const string& indent)
{
listbox->insertItem((indent + interface).c_str());
- vector<string> *tqchildren = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
- for (vector<string>::iterator ci = tqchildren->begin(); ci != tqchildren->end(); ++ci)
+ vector<string> *children = Arts::Dispatcher::the()->interfaceRepo().queryChildren(interface);
+ for (vector<string>::iterator ci = children->begin(); ci != children->end(); ++ci)
update(ci->c_str(), indent+" ");
- delete tqchildren;
+ delete children;
}
void InterfaceDlg::update()
diff --git a/arts/builder/main.cpp b/arts/builder/main.cpp
index 558f650c..229f4f61 100644
--- a/arts/builder/main.cpp
+++ b/arts/builder/main.cpp
@@ -441,7 +441,7 @@ void ArtsBuilderWindow::publish()
checkName();
structure->publish();
KMessageBox::information(this,
- i18n("The structure has been published as: '%1' on the server.").tqarg( structure->name().c_str() ));
+ i18n("The structure has been published as: '%1' on the server.").arg( structure->name().c_str() ));
}
TQString ArtsBuilderWindow::getOpenFilename(const char *pattern, const char *initialDir)
@@ -587,7 +587,7 @@ bool ArtsBuilderWindow::save(TQString filename)
if(file.status()) {
KMessageBox::sorry(this,
i18n("The file '%1' could not be opened for writing: %2")
- .tqarg(filename).tqarg(strerror(file.status())),
+ .arg(filename).arg(strerror(file.status())),
i18n("aRts Warning"));
return false;
}
@@ -597,7 +597,7 @@ bool ArtsBuilderWindow::save(TQString filename)
if(!file.close()) {
KMessageBox::sorry(this,
i18n("Saving to file '%1' could not be finished correctly: %2")
- .tqarg(filename).tqarg(strerror(file.status())),
+ .arg(filename).arg(strerror(file.status())),
i18n("aRts Warning"));
return false;
}
@@ -872,7 +872,7 @@ ArtsBuilderApp::ArtsBuilderApp(TQString filename)
mainWindow->open(filename);
} else {
KMessageBox::sorry(0,
- i18n("The specified file '%1' does not exist.").tqarg(filename),
+ i18n("The specified file '%1' does not exist.").arg(filename),
i18n("aRts Warning"));
}
}
diff --git a/arts/builder/module.cpp b/arts/builder/module.cpp
index 099f01e7..2d452dc5 100644
--- a/arts/builder/module.cpp
+++ b/arts/builder/module.cpp
@@ -24,7 +24,7 @@
#include <stdio.h>
#include <arts/debug.h>
-#include <tqpalette.h>
+#include <palette.h>
#include <tqdrawutil.h>
#include <kiconloader.h>
#include <algorithm>
diff --git a/arts/builder/portposdlg.cpp b/arts/builder/portposdlg.cpp
index 63f2546c..e165cc17 100644
--- a/arts/builder/portposdlg.cpp
+++ b/arts/builder/portposdlg.cpp
@@ -21,7 +21,7 @@
#include "portposdlg.h"
#include "structureport.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
#include <kbuttonbox.h>
@@ -46,46 +46,46 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
setCaption(i18n("aRts: Structureport View"));
- TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
- //TQHBoxLayout *contentstqlayout = new TQHBoxLayout;
+ TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
+ //TQHBoxLayout *contentslayout = new TQHBoxLayout;
// object type
/*
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
TQLabel *objectlabel = new TQLabel(this);
TQFont labelfont(objectlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
objectlabel->setFont(labelfont);
objectlabel->setText(TQString(" ")+i18n("Object type: ")+TQString(port->owner->name())+TQString(" "));
- objectlabel->tqsetAlignment(AlignCenter);
+ objectlabel->setAlignment(AlignCenter);
min_size(objectlabel);
- maintqlayout->addWidget(objectlabel);
+ mainlayout->addWidget(objectlabel);
*/
// port description
/*
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
TQLabel *portlabel = new TQLabel(this);
labelfont.setPointSize(labelfont.pointSize()*4/5);
portlabel->setFont(labelfont);
portlabel->setText(i18n("Port description: ")+ port->description);
min_size(portlabel);
- portlabel->tqsetAlignment(AlignCenter);
- maintqlayout->addWidget(portlabel);
+ portlabel->setAlignment(AlignCenter);
+ mainlayout->addWidget(portlabel);
- int labelwidth = imax(portlabel->tqsizeHint().width(),objectlabel->tqsizeHint().width());
+ int labelwidth = imax(portlabel->sizeHint().width(),objectlabel->sizeHint().width());
portlabel->setMinimumWidth(labelwidth);
objectlabel->setMinimumWidth(labelwidth);
// hruler
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(ruler);
- maintqlayout->addSpacing(5);
- maintqlayout->addLayout(contentstqlayout);
+ mainlayout->addWidget(ruler);
+ mainlayout->addSpacing(5);
+ mainlayout->addLayout(contentslayout);
*/
// list
@@ -94,21 +94,21 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
update();
listbox->setMinimumSize(100,200);
- maintqlayout->addWidget(listbox);
+ mainlayout->addWidget(listbox);
// hruler
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(ruler2);
+ mainlayout->addWidget(ruler2);
// buttons
- TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
- maintqlayout->addSpacing(5);
- maintqlayout->addLayout(buttontqlayout);
- maintqlayout->addSpacing(5);
+ TQHBoxLayout *buttonlayout = new TQHBoxLayout;
+ mainlayout->addSpacing(5);
+ mainlayout->addLayout(buttonlayout);
+ mainlayout->addSpacing(5);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -133,14 +133,14 @@ PortPosDlg::PortPosDlg(TQWidget *parent, Structure *structure) :TQDialog(parent,
TQButton *cancelbutton = bbox->addButton(i18n("Cancel"));
connect( cancelbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(reject() ) );
*/
- bbox->tqlayout();
+ bbox->layout();
//min_size(bbox);
- buttontqlayout->addWidget(bbox);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addWidget(bbox);
+ buttonlayout->addSpacing(5);
- //maintqlayout->activate();
- maintqlayout->freeze();
+ //mainlayout->activate();
+ mainlayout->freeze();
}
void PortPosDlg::raise()
@@ -247,7 +247,7 @@ void PortPosDlg::update()
}
}
}
- listbox->tqrepaint();
+ listbox->repaint();
}
void PortPosDlg::help()
diff --git a/arts/builder/propertypanel.cpp b/arts/builder/propertypanel.cpp
index df76588a..65dcd49b 100644
--- a/arts/builder/propertypanel.cpp
+++ b/arts/builder/propertypanel.cpp
@@ -26,7 +26,7 @@
#include <kdebug.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpushbutton.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
@@ -115,7 +115,7 @@ void PropertyPanel::setSelectedComponent( StructureComponent *component )
if(component->pixmap())
{
moduleIconLabel->setPixmap( *component->pixmap() );
- moduleIconLabel->setMinimumSize( moduleIconLabel->tqsizeHint() );
+ moduleIconLabel->setMinimumSize( moduleIconLabel->sizeHint() );
moduleIconLabel->show();
}
else
@@ -128,11 +128,11 @@ void PropertyPanel::setSelectedComponent( StructureComponent *component )
it != modulePorts.end(); it++)
{
TQString portTitle = (*it)->description
- + TQString(" (%1)").tqarg( (*it)->PortDesc.type().direction == Arts::output ?
+ + TQString(" (%1)").arg( (*it)->PortDesc.type().direction == Arts::output ?
i18n("OUTPUT") : i18n("INPUT") );
portCombo->insertItem( portTitle );
}
- //portCombo->setMinimumSize( portCombo->tqsizeHint() );
+ //portCombo->setMinimumSize( portCombo->sizeHint() );
setEnabled(true);
}
}
@@ -344,7 +344,7 @@ bool PropertyPanel::eventFilter( TQObject *o, TQEvent *e )
TQString entered = TQT_TQKEYEVENT(e)->text();
bool goodString = entered.length() > 0;
-// kdDebug() << TQString("pressed '%1'").tqarg(entered) << endl;
+// kdDebug() << TQString("pressed '%1'").arg(entered) << endl;
for( unsigned int i = 0; i < entered.length(); i++)
goodString = goodString && entered[i].isLetterOrNumber();
diff --git a/arts/builder/propertypanel.h b/arts/builder/propertypanel.h
index cf34fe65..cfe417f2 100644
--- a/arts/builder/propertypanel.h
+++ b/arts/builder/propertypanel.h
@@ -21,7 +21,7 @@
#define PROPERTYPANEL_H
#include "propertypanelbase.h"
-#include "tqpalette.h"
+#include "palette.h"
#include <vector>
#include <list>
diff --git a/arts/builder/propertypanelbase.ui b/arts/builder/propertypanelbase.ui
index b327b33f..0ff20382 100644
--- a/arts/builder/propertypanelbase.ui
+++ b/arts/builder/propertypanelbase.ui
@@ -314,7 +314,7 @@
<property name="name">
<cstring>tipLabel</cstring>
</property>
- <property name="tqalignment">
+ <property name="alignment">
<set>WordBreak|AlignVCenter|AlignLeft</set>
</property>
<property name="wordwrap" stdset="0">
diff --git a/arts/builder/qttableview.cpp b/arts/builder/qttableview.cpp
index f8716b44..4db8af17 100644
--- a/arts/builder/qttableview.cpp
+++ b/arts/builder/qttableview.cpp
@@ -34,8 +34,8 @@ enum ScrollBarDirtyFlags {
};
-#define HSBEXT horizontalScrollBar()->tqsizeHint().height()
-#define VSBEXT verticalScrollBar()->tqsizeHint().width()
+#define HSBEXT horizontalScrollBar()->sizeHint().height()
+#define VSBEXT verticalScrollBar()->sizeHint().width()
class TQCornerSquare : public TQWidget // internal class
@@ -88,7 +88,7 @@ void TQCornerSquare::paintEvent( TQPaintEvent * )
used by functions such as setXOffset() or maxYOffset().
\i The \e widget coordinates. (0,0) is the top-left corner of the widget,
- \e including the frame. They are used by functions such as tqrepaint().
+ \e including the frame. They are used by functions such as repaint().
\i The \e view coordinates. (0,0) is the top-left corner of the view, \e
excluding the frame. This is the least-used coordinate system; it is used by
@@ -135,7 +135,7 @@ void TQCornerSquare::paintEvent( TQPaintEvent * )
The \link setCellHeight() cell height\endlink and \link setCellWidth()
cell width\endlink are set to 0.
- Frame line tqshapes (TQFrame::HLink and TQFrame::VLine) are disallowed;
+ Frame line shapes (TQFrame::HLink and TQFrame::VLine) are disallowed;
see TQFrame::setFrameStyle().
Note that the \a f argument is \e not \link setTableFlags() table
@@ -207,7 +207,7 @@ void QtTableView::show()
/*!
- \overload void QtTableView::tqrepaint( bool erase )
+ \overload void QtTableView::repaint( bool erase )
Repaints the entire view.
*/
@@ -221,16 +221,16 @@ void QtTableView::show()
If \a w is negative, it is replaced with <code>width() - x</code>.
If \a h is negative, it is replaced with <code>height() - y</code>.
- Doing a tqrepaint() usually is faster than doing an update(), but
+ Doing a repaint() usually is faster than doing an update(), but
calling update() many times in a row will generate a single paint
event.
At present, QtTableView is the only widget that reimplements \link
- TQWidget::tqrepaint() tqrepaint()\endlink. It does this because by
+ TQWidget::repaint() repaint()\endlink. It does this because by
clearing and then repainting one cell at at time, it can make the
screen flicker less than it would otherwise. */
-void QtTableView::tqrepaint( int x, int y, int w, int h, bool erase )
+void QtTableView::repaint( int x, int y, int w, int h, bool erase )
{
if ( !isVisible() || testWState(WState_BlockUpdates) )
return;
@@ -249,7 +249,7 @@ void QtTableView::tqrepaint( int x, int y, int w, int h, bool erase )
}
/*!
- \overload void QtTableView::tqrepaint( const TQRect &r, bool erase )
+ \overload void QtTableView::repaint( const TQRect &r, bool erase )
Replaints rectangle \a r. If \a erase is TRUE draws the background
using the palette's background.
*/
@@ -288,7 +288,7 @@ void QtTableView::setNumRows( int rows )
nRows = rows;
if ( autoUpdate() && isVisible() &&
( oldLastVisible != lastRowVisible() || oldTopCell != topCell() ) )
- tqrepaint( oldTopCell != topCell() );
+ repaint( oldTopCell != topCell() );
} else {
// Be more careful - if destructing, bad things might happen.
nRows = rows;
@@ -328,7 +328,7 @@ void QtTableView::setNumCols( int cols )
if ( autoUpdate() && isVisible() ) {
int maxCol = lastColVisible();
if ( maxCol >= oldCols || maxCol >= nCols )
- tqrepaint();
+ repaint();
}
updateScrollBars( horRange );
updateFrameSize();
@@ -591,7 +591,7 @@ void QtTableView::setCellWidth( int cellWidth )
updateScrollBars( horSteps | horRange );
if ( autoUpdate() && isVisible() )
- tqrepaint();
+ repaint();
}
@@ -643,7 +643,7 @@ void QtTableView::setCellHeight( int cellHeight )
#endif
cellH = (short)cellHeight;
if ( autoUpdate() && isVisible() )
- tqrepaint();
+ repaint();
updateScrollBars( verSteps | verRange );
}
@@ -817,7 +817,7 @@ void QtTableView::setTableFlags( uint f )
(f & Tbl_snapToVGrid) != 0 && yCellDelta != 0 ) {
snapToGrid( (f & Tbl_snapToHGrid) != 0, // do snapping
(f & Tbl_snapToVGrid) != 0 );
- repaintMask |= Tbl_snapToGrid; // tqrepaint table
+ repaintMask |= Tbl_snapToGrid; // repaint table
}
}
@@ -825,7 +825,7 @@ void QtTableView::setTableFlags( uint f )
setAutoUpdate( TRUE );
updateScrollBars();
if ( isVisible() && (f & repaintMask) )
- tqrepaint();
+ repaint();
}
}
@@ -881,7 +881,7 @@ void QtTableView::clearTableFlags( uint f )
(f & Tbl_smoothVScrolling) != 0 && yCellDelta != 0 ) {
snapToGrid( (f & Tbl_smoothHScrolling) != 0, // do snapping
(f & Tbl_smoothVScrolling) != 0 );
- repaintMask |= Tbl_smoothScrolling; // tqrepaint table
+ repaintMask |= Tbl_smoothScrolling; // repaint table
}
}
if ( f & Tbl_snapToHGrid ) {
@@ -894,7 +894,7 @@ void QtTableView::clearTableFlags( uint f )
setAutoUpdate( TRUE );
updateScrollBars(); // returns immediately if nothing to do
if ( isVisible() && (f & repaintMask) )
- tqrepaint();
+ repaint();
}
}
@@ -916,20 +916,20 @@ void QtTableView::clearTableFlags( uint f )
automatically whenever it has changed in some way (for example, when a
\link setTableFlags() flag\endlink is changed).
- If \a enable is FALSE, the view does NOT tqrepaint itself or update
+ If \a enable is FALSE, the view does NOT repaint itself or update
its internal state variables when it is changed. This can be
useful to avoid flicker during large changes and is singularly
useless otherwise. Disable auto-update, do the changes, re-enable
- auto-update and call tqrepaint().
+ auto-update and call repaint().
\warning Do not leave the view in this state for a long time
(i.e., between events). If, for example, the user interacts with the
view when auto-update is off, strange things can happen.
- Setting auto-update to TRUE does not tqrepaint the view; you must call
- tqrepaint() to do this.
+ Setting auto-update to TRUE does not repaint the view; you must call
+ repaint() to do this.
- \sa autoUpdate(), tqrepaint()
+ \sa autoUpdate(), repaint()
*/
void QtTableView::setAutoUpdate( bool enable )
@@ -963,7 +963,7 @@ void QtTableView::updateCell( int row, int col, bool erase )
TQRect uR = TQRect( xPos, yPos,
cellW ? cellW : cellWidth(col),
cellH ? cellH : cellHeight(row) );
- tqrepaint( uR.intersect(viewRect()), erase );
+ repaint( uR.intersect(viewRect()), erase );
}
@@ -1379,13 +1379,13 @@ void QtTableView::paintEvent( TQPaintEvent *e )
// Note that this needs to be done regardless whether we do
// eraseInPaint or not. Reason: a subclass may implement
- // flicker-freeness and encourage the use of tqrepaint(FALSE).
+ // flicker-freeness and encourage the use of repaint(FALSE).
// The subclass, however, cannot draw all pixels, just those
// inside the cells. So QtTableView is reponsible for all pixels
// outside the cells.
TQRect viewR = viewRect();
- const TQColorGroup g = tqcolorGroup();
+ const TQColorGroup g = colorGroup();
if ( xPos <= maxX ) {
TQRect r = viewR;
@@ -1426,7 +1426,7 @@ void QtTableView::resizeEvent( TQResizeEvent * )
void QtTableView::updateView()
{
- tqrepaint( viewRect() );
+ repaint( viewRect() );
}
/*!
@@ -1443,7 +1443,7 @@ TQScrollBar *QtTableView::verticalScrollBar() const
#ifndef TQT_NO_CURSOR
sb->setCursor( arrowCursor );
#endif
- sb->resize( sb->tqsizeHint() ); // height is irrelevant
+ sb->resize( sb->sizeHint() ); // height is irrelevant
Q_CHECK_PTR(sb);
sb->setTracking( FALSE );
sb->setFocusPolicy( TQ_NoFocus );
@@ -1474,7 +1474,7 @@ TQScrollBar *QtTableView::horizontalScrollBar() const
#ifndef TQT_NO_CURSOR
sb->setCursor( arrowCursor );
#endif
- sb->resize( sb->tqsizeHint() ); // width is irrelevant
+ sb->resize( sb->sizeHint() ); // width is irrelevant
sb->setFocusPolicy( TQ_NoFocus );
Q_CHECK_PTR(sb);
sb->setTracking( FALSE );
@@ -1522,7 +1522,7 @@ void QtTableView::setHorScrollBar( bool on, bool update )
else
sbDirty = sbDirty | verMask;
if ( hideScrollBar && isVisible() )
- tqrepaint( hScrollBar->x(), hScrollBar->y(),
+ repaint( hScrollBar->x(), hScrollBar->y(),
width() - hScrollBar->x(), hScrollBar->height() );
}
if ( update )
@@ -1561,7 +1561,7 @@ void QtTableView::setVerScrollBar( bool on, bool update )
else
sbDirty = sbDirty | horMask;
if ( hideScrollBar && isVisible() )
- tqrepaint( vScrollBar->x(), vScrollBar->y(),
+ repaint( vScrollBar->x(), vScrollBar->y(),
vScrollBar->width(), height() - vScrollBar->y() );
}
if ( update )
@@ -2006,7 +2006,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & horValue )
hScrollBar->setValue( xOffs );
- // show scrollbar only when it has a sane tqgeometry
+ // show scrollbar only when it has a sane geometry
if ( !hScrollBar->isVisible() )
hScrollBar->show();
}
@@ -2030,7 +2030,7 @@ void QtTableView::updateScrollBars( uint f )
if ( sbDirty & verValue )
vScrollBar->setValue( yOffs );
- // show scrollbar only when it has a sane tqgeometry
+ // show scrollbar only when it has a sane geometry
if ( !vScrollBar->isVisible() )
vScrollBar->show();
}
@@ -2253,7 +2253,7 @@ void QtTableView::showOrHideScrollBars()
Call this function when the table view's total size is changed;
typically because the result of cellHeight() or cellWidth() have changed.
- This function does not tqrepaint the widget.
+ This function does not repaint the widget.
*/
void QtTableView::updateTableSize()
diff --git a/arts/builder/qttableview.h b/arts/builder/qttableview.h
index 7d4f14e2..3160a38a 100644
--- a/arts/builder/qttableview.h
+++ b/arts/builder/qttableview.h
@@ -32,9 +32,9 @@ public:
virtual void setPalette( const TQPalette & );
void show();
- void tqrepaint( bool erase=TRUE );
- void tqrepaint( int x, int y, int w, int h, bool erase=TRUE );
- void tqrepaint( const TQRect &, bool erase=TRUE );
+ void repaint( bool erase=TRUE );
+ void repaint( int x, int y, int w, int h, bool erase=TRUE );
+ void repaint( const TQRect &, bool erase=TRUE );
protected:
QtTableView( TQWidget *parent=0, const char *name=0, WFlags f=0 );
@@ -235,11 +235,11 @@ inline TQRect QtTableView::cellUpdateRect() const
inline bool QtTableView::autoUpdate() const
{ return isUpdatesEnabled(); }
-inline void QtTableView::tqrepaint( bool erase )
-{ tqrepaint( 0, 0, width(), height(), erase ); }
+inline void QtTableView::repaint( bool erase )
+{ repaint( 0, 0, width(), height(), erase ); }
-inline void QtTableView::tqrepaint( const TQRect &r, bool erase )
-{ tqrepaint( r.x(), r.y(), r.width(), r.height(), erase ); }
+inline void QtTableView::repaint( const TQRect &r, bool erase )
+{ repaint( r.x(), r.y(), r.width(), r.height(), erase ); }
inline void QtTableView::updateScrollBars()
{ updateScrollBars( 0 ); }
diff --git a/arts/builder/retrievedlg.cpp b/arts/builder/retrievedlg.cpp
index 5b738471..94dca3d4 100644
--- a/arts/builder/retrievedlg.cpp
+++ b/arts/builder/retrievedlg.cpp
@@ -20,7 +20,7 @@
*/
#include "retrievedlg.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqlistbox.h>
#include <kbuttonbox.h>
@@ -37,33 +37,33 @@
#include <tqpushbutton.h>
static void min_size(TQWidget *w) {
- w->setMinimumSize(w->tqsizeHint());
+ w->setMinimumSize(w->sizeHint());
}
RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
{
setCaption(i18n("Retrieve Structure From Server"));
- TQVBoxLayout *maintqlayout = new TQVBoxLayout(this);
+ TQVBoxLayout *mainlayout = new TQVBoxLayout(this);
// caption label: "Synthesis running..."
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
TQLabel *captionlabel = new TQLabel(this);
TQFont labelfont(captionlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
captionlabel->setFont(labelfont);
captionlabel->setText(TQString(" ")+i18n("Published structures")+TQString(" "));
- captionlabel->tqsetAlignment(AlignCenter);
+ captionlabel->setAlignment(AlignCenter);
min_size(captionlabel);
- maintqlayout->addWidget(captionlabel);
+ mainlayout->addWidget(captionlabel);
// hruler
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator *ruler2 = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(ruler2);
- maintqlayout->addSpacing(5);
+ mainlayout->addWidget(ruler2);
+ mainlayout->addSpacing(5);
// listwidget
@@ -85,23 +85,23 @@ RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
listbox->insertItem((*ni).c_str());
#endif
- maintqlayout->addWidget(listbox);
+ mainlayout->addWidget(listbox);
// hruler
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator *ruler = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(ruler);
- maintqlayout->addSpacing(5);
+ mainlayout->addWidget(ruler);
+ mainlayout->addSpacing(5);
// buttons
- TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
- maintqlayout->addSpacing(5);
- maintqlayout->addLayout(buttontqlayout);
- maintqlayout->addSpacing(5);
+ TQHBoxLayout *buttonlayout = new TQHBoxLayout;
+ mainlayout->addSpacing(5);
+ mainlayout->addLayout(buttonlayout);
+ mainlayout->addSpacing(5);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -113,12 +113,12 @@ RetrieveDlg::RetrieveDlg(TQWidget *parent) :TQDialog(parent,"X", TRUE)
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
connect( okbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(accept() ) );
- bbox->tqlayout();
+ bbox->layout();
- buttontqlayout->addWidget(bbox);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addWidget(bbox);
+ buttonlayout->addSpacing(5);
- maintqlayout->freeze();
+ mainlayout->freeze();
}
TQString RetrieveDlg::result()
diff --git a/arts/builder/retrievedlg.h b/arts/builder/retrievedlg.h
index 51649c4f..dfc079e1 100644
--- a/arts/builder/retrievedlg.h
+++ b/arts/builder/retrievedlg.h
@@ -29,7 +29,7 @@
#include <tqlabel.h>
#include <tqscrollbar.h>
#include <tqlineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlistbox.h>
#include <string>
diff --git a/arts/builder/structureport.cpp b/arts/builder/structureport.cpp
index e61fa2a9..b8d59d1e 100644
--- a/arts/builder/structureport.cpp
+++ b/arts/builder/structureport.cpp
@@ -22,7 +22,7 @@
#include "structureport.h"
#include "drawutils.h"
#include <tqpainter.h>
-#include <tqpalette.h>
+#include <palette.h>
#include <tqdrawutil.h>
#include <tqbitmap.h>
#include <assert.h>
diff --git a/arts/builder/execdlg.cpp b/arts/builder/execdlg.cpp
index 790691e8..8ead524a 100644
--- a/arts/builder/execdlg.cpp
+++ b/arts/builder/execdlg.cpp
@@ -20,7 +20,7 @@
*/
#include <tqfile.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqbuttongroup.h>
#include <tqradiobutton.h>
@@ -41,7 +41,7 @@
#ifndef KDE_USE_FINAL
static void min_size(TQWidget *w) {
- w->setMinimumSize(w->tqsizeHint());
+ w->setMinimumSize(w->sizeHint());
}
#endif
@@ -53,19 +53,19 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
setCaption(i18n("aRts Module Execution"));
- maintqlayout = new TQVBoxLayout(this);
+ mainlayout = new TQVBoxLayout(this);
// caption label: "Synthesis running..."
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
TQLabel *captionlabel = new TQLabel(this);
TQFont labelfont(captionlabel->font());
labelfont.setPointSize(labelfont.pointSize()*3/2);
captionlabel->setFont(labelfont);
captionlabel->setText(TQString(" ")+i18n("Synthesis running...")+TQString(" "));
- captionlabel->tqsetAlignment(AlignCenter);
+ captionlabel->setAlignment(AlignCenter);
min_size(captionlabel);
- maintqlayout->addWidget(captionlabel);
+ mainlayout->addWidget(captionlabel);
cpuusagelabel = new TQLabel(this);
cpuusagelabel->setText(i18n("CPU usage: unknown"));
@@ -78,41 +78,41 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
cpuusagetimer->start( 2000, false );
min_size(cpuusagelabel);
- maintqlayout->addWidget(cpuusagelabel);
+ mainlayout->addWidget(cpuusagelabel);
-// ruler above the slidertqlayout
+// ruler above the sliderlayout
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
KSeparator* sep = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(sep);
- maintqlayout->addSpacing(5);
+ mainlayout->addWidget(sep);
+ mainlayout->addSpacing(5);
// sliders, controlpanels
- slidertqlayout = new TQVBoxLayout;
- maintqlayout->addLayout(slidertqlayout);
+ sliderlayout = new TQVBoxLayout;
+ mainlayout->addLayout(sliderlayout);
#if 0 /* PORT */
this->GUIServer = GUIServer;
GUIServer->setGlobalParent(this);
- GUIServer->setGlobalLayout(slidertqlayout);
+ GUIServer->setGlobalLayout(sliderlayout);
#endif
-// hruler below the slidertqlayout
+// hruler below the sliderlayout
- maintqlayout->addSpacing(5);
+ mainlayout->addSpacing(5);
sep = new KSeparator( KSeparator::HLine, this);
- maintqlayout->addWidget(sep);
- maintqlayout->addSpacing(5);
+ mainlayout->addWidget(sep);
+ mainlayout->addSpacing(5);
// buttons
- TQHBoxLayout *buttontqlayout = new TQHBoxLayout;
- maintqlayout->addSpacing(5);
- maintqlayout->addLayout(buttontqlayout);
- maintqlayout->addSpacing(5);
+ TQHBoxLayout *buttonlayout = new TQHBoxLayout;
+ mainlayout->addSpacing(5);
+ mainlayout->addLayout(buttonlayout);
+ mainlayout->addSpacing(5);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addSpacing(5);
KButtonBox *bbox = new KButtonBox(this);
bbox->addButton(KStdGuiItem::help(), TQT_TQOBJECT(this), TQT_SLOT( help() ));
@@ -125,18 +125,18 @@ ExecDlg::ExecDlg(TQWidget *parent, ExecutableStructure *structure)
TQButton *okbutton = bbox->addButton(KStdGuiItem::ok());
connect( okbutton, TQT_SIGNAL( clicked() ), TQT_SLOT(accept() ) );
- bbox->tqlayout();
+ bbox->layout();
//min_size(bbox);
- buttontqlayout->addWidget(bbox);
- buttontqlayout->addSpacing(5);
+ buttonlayout->addWidget(bbox);
+ buttonlayout->addSpacing(5);
-// maintqlayout->freeze();
+// mainlayout->freeze();
}
void ExecDlg::start()
{
- maintqlayout->freeze();
+ mainlayout->freeze();
}
void ExecDlg::guiServerTick()
@@ -151,7 +151,7 @@ void ExecDlg::updateCpuUsage()
#if 0 /* TODO:PORT */
char cpuusage[100];
- ArtsCorba::tqStatus s = Synthesizer->gettqStatus();
+ ArtsCorba::Status s = Synthesizer->getStatus();
if(s.halted)
{
cpuusagetimer->stop();